AsyncQueryMsgFns

Trait AsyncQueryMsgFns 

pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn config_async(&self) -> Result<ConfigResponse, CwEnvError> { ... } async fn module_versions_async( &self, ids: Vec<String>, ) -> Result<ModuleVersionsResponse, CwEnvError> { ... } async fn module_addresses_async( &self, ids: Vec<String>, ) -> Result<ModuleAddressesResponse, CwEnvError> { ... } async fn module_infos_async( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<ModuleInfosResponse, CwEnvError> { ... } async fn info_async(&self) -> Result<InfoResponse, CwEnvError> { ... } async fn sub_account_ids_async( &self, limit: Option<u8>, start_after: Option<u32>, ) -> Result<SubAccountIdsResponse, CwEnvError> { ... } async fn top_level_owner_async( &self, ) -> Result<TopLevelOwnerResponse, CwEnvError> { ... } async fn ownership_async(&self) -> Result<Ownership<String>, CwEnvError> { ... } async fn authenticator_by_id_async( &self, id: u8, ) -> Result<Binary, CwEnvError> { ... } async fn authenticator_i_ds_async(&self) -> Result<Binary, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn config_async(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

async fn module_versions_async( &self, ids: Vec<String>, ) -> Result<ModuleVersionsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleVersions variant

async fn module_addresses_async( &self, ids: Vec<String>, ) -> Result<ModuleAddressesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleAddresses variant

async fn module_infos_async( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<ModuleInfosResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleInfos variant

async fn info_async(&self) -> Result<InfoResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Info variant

async fn sub_account_ids_async( &self, limit: Option<u8>, start_after: Option<u32>, ) -> Result<SubAccountIdsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::SubAccountIds variant

async fn top_level_owner_async( &self, ) -> Result<TopLevelOwnerResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::TopLevelOwner variant

async fn ownership_async(&self) -> Result<Ownership<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

async fn authenticator_by_id_async(&self, id: u8) -> Result<Binary, CwEnvError>

Automatically generated wrapper around QueryMsg::AuthenticatorByID variant

async fn authenticator_i_ds_async(&self) -> Result<Binary, CwEnvError>

Automatically generated wrapper around QueryMsg::AuthenticatorIDs variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.