QueryMsgFns

Trait QueryMsgFns 

pub trait QueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods fn config(&self) -> Result<ConfigResponse, CwEnvError> { ... } fn module_versions( &self, ids: Vec<String>, ) -> Result<ModuleVersionsResponse, CwEnvError> { ... } fn module_addresses( &self, ids: Vec<String>, ) -> Result<ModuleAddressesResponse, CwEnvError> { ... } fn module_infos( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<ModuleInfosResponse, CwEnvError> { ... } fn info(&self) -> Result<InfoResponse, CwEnvError> { ... } fn sub_account_ids( &self, limit: Option<u8>, start_after: Option<u32>, ) -> Result<SubAccountIdsResponse, CwEnvError> { ... } fn top_level_owner(&self) -> Result<TopLevelOwnerResponse, CwEnvError> { ... } fn ownership(&self) -> Result<Ownership<String>, CwEnvError> { ... } fn authenticator_by_id(&self, id: u8) -> Result<Binary, CwEnvError> { ... } fn authenticator_i_ds(&self) -> Result<Binary, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn config(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

fn module_versions( &self, ids: Vec<String>, ) -> Result<ModuleVersionsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleVersions variant

fn module_addresses( &self, ids: Vec<String>, ) -> Result<ModuleAddressesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleAddresses variant

fn module_infos( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<ModuleInfosResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleInfos variant

fn info(&self) -> Result<InfoResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Info variant

fn sub_account_ids( &self, limit: Option<u8>, start_after: Option<u32>, ) -> Result<SubAccountIdsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::SubAccountIds variant

fn top_level_owner(&self) -> Result<TopLevelOwnerResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::TopLevelOwner variant

fn ownership(&self) -> Result<Ownership<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

fn authenticator_by_id(&self, id: u8) -> Result<Binary, CwEnvError>

Automatically generated wrapper around QueryMsg::AuthenticatorByID variant

fn authenticator_i_ds(&self) -> Result<Binary, CwEnvError>

Automatically generated wrapper around QueryMsg::AuthenticatorIDs variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> QueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.