BaseQueryMsgFns

Trait BaseQueryMsgFns 

pub trait BaseQueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where BaseQueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods fn base_config(&self) -> Result<AdapterConfigResponse, CwEnvError> { ... } fn authorized_addresses( &self, account_address: impl Into<String>, ) -> Result<AuthorizedAddressesResponse, CwEnvError> { ... } fn module_data(&self) -> Result<ModuleDataResponse, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn base_config(&self) -> Result<AdapterConfigResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::BaseConfig variant

fn authorized_addresses( &self, account_address: impl Into<String>, ) -> Result<AuthorizedAddressesResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::AuthorizedAddresses variant

fn module_data(&self) -> Result<ModuleDataResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::ModuleData variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> BaseQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where BaseQueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.