AsyncBaseQueryMsgFns

Trait AsyncBaseQueryMsgFns 

pub trait AsyncBaseQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where BaseQueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn base_config_async(&self) -> Result<AppConfigResponse, CwEnvError> { ... } async fn base_admin_async(&self) -> Result<AdminResponse, CwEnvError> { ... } async fn module_data_async(&self) -> Result<ModuleDataResponse, CwEnvError> { ... } async fn top_level_owner_async( &self, ) -> Result<TopLevelOwnerResponse, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn base_config_async(&self) -> Result<AppConfigResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::BaseConfig variant

async fn base_admin_async(&self) -> Result<AdminResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::BaseAdmin variant

async fn module_data_async(&self) -> Result<ModuleDataResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::ModuleData variant

async fn top_level_owner_async( &self, ) -> Result<TopLevelOwnerResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::TopLevelOwner variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncBaseQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where BaseQueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.