BaseQueryMsgFns

Trait BaseQueryMsgFns 

pub trait BaseQueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where BaseQueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods fn base_config(&self) -> Result<AppConfigResponse, CwEnvError> { ... } fn base_admin(&self) -> Result<AdminResponse, CwEnvError> { ... } fn module_data(&self) -> Result<ModuleDataResponse, CwEnvError> { ... } fn top_level_owner(&self) -> Result<TopLevelOwnerResponse, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn base_config(&self) -> Result<AppConfigResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::BaseConfig variant

fn base_admin(&self) -> Result<AdminResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::BaseAdmin variant

fn module_data(&self) -> Result<ModuleDataResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::ModuleData variant

fn top_level_owner(&self) -> Result<TopLevelOwnerResponse, CwEnvError>

Automatically generated wrapper around BaseQueryMsg::TopLevelOwner variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> BaseQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where BaseQueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.