Module abstract_std::ibc
source · Structs
- Callback from modules, that is turned into an IbcResponseMsg by the ibc client A callback can only be sent to itself
- IbcResponseMsg should be de/serialized under
IbcCallback()variant in a ExecuteMsg
IbcCallback() variant in a ExecuteMsg