ExecuteMsgFns

Trait ExecuteMsgFns 

pub trait ExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>
where ExecuteMsg: Into<CwOrchExecuteMsgType>,
{ // Provided methods fn update_ownership( &self, arg0: Action, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn register_infrastructure( &self, chain: TruncatedChainId, host: impl Into<String>, note: impl Into<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn send_funds( &self, host_chain: TruncatedChainId, memo: Option<String>, receiver: Option<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn send_funds_with_actions( &self, actions: Vec<Binary>, host_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn register( &self, host_chain: TruncatedChainId, install_modules: Vec<ModuleInstallConfig>, namespace: Option<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn module_ibc_action( &self, host_chain: TruncatedChainId, msg: Binary, target_module: ModuleInfo, callback: Option<Callback>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn ibc_query( &self, callback: Callback, host_chain: TruncatedChainId, queries: Vec<QueryRequest<ModuleQuery>>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn remote_action( &self, action: HostAction, host_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn remove_host( &self, host_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn callback( &self, arg0: CallbackMessage, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn update_ownership( &self, arg0: Action, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateOwnership variant

fn register_infrastructure( &self, chain: TruncatedChainId, host: impl Into<String>, note: impl Into<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RegisterInfrastructure variant

fn send_funds( &self, host_chain: TruncatedChainId, memo: Option<String>, receiver: Option<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::SendFunds variant

fn send_funds_with_actions( &self, actions: Vec<Binary>, host_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::SendFundsWithActions variant

fn register( &self, host_chain: TruncatedChainId, install_modules: Vec<ModuleInstallConfig>, namespace: Option<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Register variant

fn module_ibc_action( &self, host_chain: TruncatedChainId, msg: Binary, target_module: ModuleInfo, callback: Option<Callback>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ModuleIbcAction variant

fn ibc_query( &self, callback: Callback, host_chain: TruncatedChainId, queries: Vec<QueryRequest<ModuleQuery>>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::IbcQuery variant

fn remote_action( &self, action: HostAction, host_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RemoteAction variant

fn remove_host( &self, host_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RemoveHost variant

fn callback( &self, arg0: CallbackMessage, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Callback variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContract
where ExecuteMsg: Into<CwOrchExecuteMsgType>, SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,

Available on non-WebAssembly only.