AsyncQueryMsgFns

Trait AsyncQueryMsgFns 

pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn ownership_async(&self) -> Result<Ownership<Addr>, CwEnvError> { ... } async fn config_async(&self) -> Result<ConfigResponse, CwEnvError> { ... } async fn client_proxies_async( &self, limit: Option<u32>, start_after: Option<String>, ) -> Result<ClientProxiesResponse, CwEnvError> { ... } async fn client_proxy_async( &self, chain: impl Into<String>, ) -> Result<ClientProxyResponse, CwEnvError> { ... } async fn module_query_async( &self, msg: Binary, target_module: InstalledModuleIdentification, ) -> Result<Binary, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn ownership_async(&self) -> Result<Ownership<Addr>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

async fn config_async(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

async fn client_proxies_async( &self, limit: Option<u32>, start_after: Option<String>, ) -> Result<ClientProxiesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ClientProxies variant

async fn client_proxy_async( &self, chain: impl Into<String>, ) -> Result<ClientProxyResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ClientProxy variant

async fn module_query_async( &self, msg: Binary, target_module: InstalledModuleIdentification, ) -> Result<Binary, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleQuery variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.