ExecuteMsgFns

Trait ExecuteMsgFns 

pub trait ExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>
where ExecuteMsg: Into<CwOrchExecuteMsgType>,
{ // Provided methods fn update_ownership( &self, arg0: Action, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn register_chain_proxy( &self, chain: TruncatedChainId, proxy: impl Into<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn remove_chain_proxy( &self, chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn ibc_execute( &self, account_address: impl Into<String>, account_id: AccountId, action: HostAction, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn module_execute( &self, msg: Binary, source_module: InstalledModuleIdentification, target_module: ModuleInfo, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn fund( &self, src_account: AccountId, src_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn update_ownership( &self, arg0: Action, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateOwnership variant

fn register_chain_proxy( &self, chain: TruncatedChainId, proxy: impl Into<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RegisterChainProxy variant

fn remove_chain_proxy( &self, chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RemoveChainProxy variant

fn ibc_execute( &self, account_address: impl Into<String>, account_id: AccountId, action: HostAction, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Execute variant

fn module_execute( &self, msg: Binary, source_module: InstalledModuleIdentification, target_module: ModuleInfo, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ModuleExecute variant

fn fund( &self, src_account: AccountId, src_chain: TruncatedChainId, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::Fund variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContract
where ExecuteMsg: Into<CwOrchExecuteMsgType>, SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,

Available on non-WebAssembly only.