QueryMsgFns

Trait QueryMsgFns 

pub trait QueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods fn ownership(&self) -> Result<Ownership<Addr>, CwEnvError> { ... } fn config(&self) -> Result<ConfigResponse, CwEnvError> { ... } fn client_proxies( &self, limit: Option<u32>, start_after: Option<String>, ) -> Result<ClientProxiesResponse, CwEnvError> { ... } fn client_proxy( &self, chain: impl Into<String>, ) -> Result<ClientProxyResponse, CwEnvError> { ... } fn module_query( &self, msg: Binary, target_module: InstalledModuleIdentification, ) -> Result<Binary, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn ownership(&self) -> Result<Ownership<Addr>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

fn config(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

fn client_proxies( &self, limit: Option<u32>, start_after: Option<String>, ) -> Result<ClientProxiesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ClientProxies variant

fn client_proxy( &self, chain: impl Into<String>, ) -> Result<ClientProxyResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ClientProxy variant

fn module_query( &self, msg: Binary, target_module: InstalledModuleIdentification, ) -> Result<Binary, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleQuery variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> QueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.