QueryMsgFns

Trait QueryMsgFns 

pub trait QueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods fn config(&self) -> Result<ConfigResponse, CwEnvError> { ... } fn simulate_install_modules( &self, modules: Vec<ModuleInfo>, ) -> Result<SimulateInstallModulesResponse, CwEnvError> { ... } fn ownership(&self) -> Result<Ownership<String>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn config(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

fn simulate_install_modules( &self, modules: Vec<ModuleInfo>, ) -> Result<SimulateInstallModulesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::SimulateInstallModules variant

fn ownership(&self) -> Result<Ownership<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> QueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.