Enum abstract_std::objects::gov_type::GovernanceDetails
source · #[non_exhaustive]pub enum GovernanceDetails<T: AddressLike> {
Monarchy {
monarch: T,
},
SubAccount {
manager: T,
proxy: T,
},
External {
governance_address: T,
governance_type: String,
},
Renounced {},
NFT {
collection_addr: T,
token_id: String,
},
}Expand description
Governance types
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Monarchy
A single address is admin
Fields

monarch: TThe monarch’s address
SubAccount
Used when the account is a sub-account of another account.
Fields

manager: TThe manager of the account of which this account is the sub-account.

proxy: TThe proxy of the account of which this account is the sub-account.
External
An external governance source
Fields

governance_address: TThe external contract address
Renounced
Renounced account This account no longer has an owner and cannot be used.
NFT
Implementations
sourceimpl GovernanceDetails<String>
impl GovernanceDetails<String>
sourcepub fn verify(
self,
deps: Deps<'_>,
version_control_addr: Addr,
) -> Result<GovernanceDetails<Addr>, AbstractError>
pub fn verify( self, deps: Deps<'_>, version_control_addr: Addr, ) -> Result<GovernanceDetails<Addr>, AbstractError>
Verify the governance details and convert to Self<Addr>
sourceimpl GovernanceDetails<Addr>
impl GovernanceDetails<Addr>
sourcepub fn owner_address(&self, querier: &QuerierWrapper<'_>) -> Option<Addr>
pub fn owner_address(&self, querier: &QuerierWrapper<'_>) -> Option<Addr>
Get the owner address from the governance details