Module module

Module module 

Structs

Module
ModuleInfo
Stores the namespace, name, and version of an Abstract module.
ModuleInitMsg

Enums

ModuleStatus
Module status
ModuleVersion
Monetization
Module Monetization

Functions

assert_module_data_validity
Assert that the provided module has the same data stored under the cw2 and module data keys.
validate_name
Validate attributes of a ModuleInfo. We use the same conventions as Rust package names. See https://github.com/rust-lang/api-guidelines/discussions/29

Type Aliases

ModuleId
ID of the module
ModuleMetadata
Module Metadata String