Module cw721

Module cw721 

This module used internally, for Nft Owners and could be removed at any point if cw721 will get upgraded to cosmwasm 2.0+

Structs

OwnerOfResponse
Expiration represents a point in time when some event happens. It can compare with a BlockInfo and will return is_expired() == true once the condition is hit (and for every block in the future)

Enums

Cw721QueryMsg