AsyncQueryMsgFns

Trait AsyncQueryMsgFns 

pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn accounts_async( &self, account_ids: Vec<AccountId>, ) -> Result<AccountsResponse, CwEnvError> { ... } async fn modules_async( &self, infos: Vec<ModuleInfo>, ) -> Result<ModulesResponse, CwEnvError> { ... } async fn namespaces_async( &self, accounts: Vec<AccountId>, ) -> Result<NamespacesResponse, CwEnvError> { ... } async fn namespace_async( &self, namespace: Namespace, ) -> Result<NamespaceResponse, CwEnvError> { ... } async fn config_async(&self) -> Result<ConfigResponse, CwEnvError> { ... } async fn account_list_async( &self, limit: Option<u8>, start_after: Option<AccountId>, ) -> Result<AccountListResponse, CwEnvError> { ... } async fn module_list_async( &self, filter: Option<ModuleFilter>, limit: Option<u8>, start_after: Option<ModuleInfo>, ) -> Result<ModulesListResponse, CwEnvError> { ... } async fn namespace_list_async( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<NamespaceListResponse, CwEnvError> { ... } async fn ownership_async(&self) -> Result<Ownership<String>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn accounts_async( &self, account_ids: Vec<AccountId>, ) -> Result<AccountsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Accounts variant

async fn modules_async( &self, infos: Vec<ModuleInfo>, ) -> Result<ModulesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Modules variant

async fn namespaces_async( &self, accounts: Vec<AccountId>, ) -> Result<NamespacesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Namespaces variant

async fn namespace_async( &self, namespace: Namespace, ) -> Result<NamespaceResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Namespace variant

async fn config_async(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

async fn account_list_async( &self, limit: Option<u8>, start_after: Option<AccountId>, ) -> Result<AccountListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::AccountList variant

async fn module_list_async( &self, filter: Option<ModuleFilter>, limit: Option<u8>, start_after: Option<ModuleInfo>, ) -> Result<ModulesListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleList variant

async fn namespace_list_async( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<NamespaceListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::NamespaceList variant

async fn ownership_async(&self) -> Result<Ownership<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.