ExecuteMsgFns

Trait ExecuteMsgFns 

pub trait ExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>
where ExecuteMsg: Into<CwOrchExecuteMsgType>,
{ // Provided methods fn remove_module( &self, module: ModuleInfo, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn yank_module( &self, module: ModuleInfo, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn propose_modules( &self, modules: Vec<ModuleMapEntry>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn update_module_configuration( &self, module_name: impl Into<String>, namespace: Namespace, update_module: UpdateModule, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn approve_or_reject_modules( &self, approves: Vec<ModuleInfo>, rejects: Vec<ModuleInfo>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn claim_namespace( &self, account_id: AccountId, namespace: impl Into<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn forgo_namespace( &self, namespaces: Vec<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn add_account( &self, creator: impl Into<String>, namespace: Option<String>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn update_config( &self, namespace_registration_fee: Option<Clearable<Coin>>, security_enabled: Option<bool>, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } fn update_ownership( &self, arg0: Action, ) -> Result<TxResponse<Chain>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn remove_module( &self, module: ModuleInfo, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::RemoveModule variant

fn yank_module( &self, module: ModuleInfo, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::YankModule variant

fn propose_modules( &self, modules: Vec<ModuleMapEntry>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ProposeModules variant

fn update_module_configuration( &self, module_name: impl Into<String>, namespace: Namespace, update_module: UpdateModule, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateModuleConfiguration variant

fn approve_or_reject_modules( &self, approves: Vec<ModuleInfo>, rejects: Vec<ModuleInfo>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ApproveOrRejectModules variant

fn claim_namespace( &self, account_id: AccountId, namespace: impl Into<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ClaimNamespace variant

fn forgo_namespace( &self, namespaces: Vec<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::ForgoNamespace variant

fn add_account( &self, creator: impl Into<String>, namespace: Option<String>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::AddAccount variant

fn update_config( &self, namespace_registration_fee: Option<Clearable<Coin>>, security_enabled: Option<bool>, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateConfig variant

fn update_ownership( &self, arg0: Action, ) -> Result<TxResponse<Chain>, CwEnvError>

Automatically generated wrapper around ExecuteMsg::UpdateOwnership variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContract
where ExecuteMsg: Into<CwOrchExecuteMsgType>, SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,

Available on non-WebAssembly only.