QueryMsgFns

Trait QueryMsgFns 

pub trait QueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods fn accounts( &self, account_ids: Vec<AccountId>, ) -> Result<AccountsResponse, CwEnvError> { ... } fn modules( &self, infos: Vec<ModuleInfo>, ) -> Result<ModulesResponse, CwEnvError> { ... } fn namespaces( &self, accounts: Vec<AccountId>, ) -> Result<NamespacesResponse, CwEnvError> { ... } fn namespace( &self, namespace: Namespace, ) -> Result<NamespaceResponse, CwEnvError> { ... } fn config(&self) -> Result<ConfigResponse, CwEnvError> { ... } fn account_list( &self, limit: Option<u8>, start_after: Option<AccountId>, ) -> Result<AccountListResponse, CwEnvError> { ... } fn module_list( &self, filter: Option<ModuleFilter>, limit: Option<u8>, start_after: Option<ModuleInfo>, ) -> Result<ModulesListResponse, CwEnvError> { ... } fn namespace_list( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<NamespaceListResponse, CwEnvError> { ... } fn ownership(&self) -> Result<Ownership<String>, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

fn accounts( &self, account_ids: Vec<AccountId>, ) -> Result<AccountsResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Accounts variant

fn modules(&self, infos: Vec<ModuleInfo>) -> Result<ModulesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Modules variant

fn namespaces( &self, accounts: Vec<AccountId>, ) -> Result<NamespacesResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Namespaces variant

fn namespace( &self, namespace: Namespace, ) -> Result<NamespaceResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Namespace variant

fn config(&self) -> Result<ConfigResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::Config variant

fn account_list( &self, limit: Option<u8>, start_after: Option<AccountId>, ) -> Result<AccountListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::AccountList variant

fn module_list( &self, filter: Option<ModuleFilter>, limit: Option<u8>, start_after: Option<ModuleInfo>, ) -> Result<ModulesListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::ModuleList variant

fn namespace_list( &self, limit: Option<u8>, start_after: Option<String>, ) -> Result<NamespaceListResponse, CwEnvError>

Automatically generated wrapper around QueryMsg::NamespaceList variant

fn ownership(&self) -> Result<Ownership<String>, CwEnvError>

Automatically generated wrapper around QueryMsg::Ownership variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> QueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.