pub trait BaseExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>where
BaseExecuteMsg: Into<CwOrchExecuteMsgType>,{ }Expand description
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> BaseExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContractwhere
BaseExecuteMsg: Into<CwOrchExecuteMsgType>,
SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,
Available on non-WebAssembly only.